CCL: /home/chisarie/Documents/lsst_ccl/CCL/src/ccl_cls.c File Reference

CCL

Data Structures | Functions
ccl_cls.c File Reference
`#include "ccl_cls.h"`
`#include "ccl_power.h"`
`#include "ccl_background.h"`
`#include "ccl_error.h"`
`#include "ccl_utils.h"`
`#include <stdlib.h>`
`#include <math.h>`
`#include <stdio.h>`
`#include <string.h>`
`#include "gsl/gsl_errno.h"`
`#include "gsl/gsl_integration.h"`
`#include "ccl_params.h"`

## Data Structures
struct | IntLensPar
struct | IntMagPar
struct | IntClPar

## Functions
CCL_ClTracer * | ccl_cl_tracer_new (ccl_cosmology *cosmo, int tracer_type, int has_rsd, int has_magnification, int has_intrinsic_alignment, int nz_n, double *z_n, double *n, int nz_b, double *z_b, double *b, int nz_s, double *z_s, double *s, int nz_ba, double *z_ba, double *ba, int nz_rf, double *z_rf, double *rf, int *status)
void | ccl_cl_tracer_free (CCL_ClTracer *clt)
CCL_ClTracer * | ccl_cl_tracer_number_counts_new (ccl_cosmology *cosmo, int has_rsd, int has_magnification, int nz_n, double *z_n, double *n, int nz_b, double *z_b, double *b, int nz_s, double *z_s, double *s, int *status)
CCL_ClTracer * | ccl_cl_tracer_number_counts_simple_new (ccl_cosmology *cosmo, int nz_n, double *z_n, double *n, int nz_b, double *z_b, double *b, int *status)
CCL_ClTracer * | ccl_cl_tracer_lensing_new (ccl_cosmology *cosmo, int has_alignment, int nz_n, double *z_n, double *n, int nz_ba, double *z_ba, double *ba, int nz_rf, double *z_rf, double *rf, int *status)
CCL_ClTracer * | ccl_cl_tracer_lensing_simple_new (ccl_cosmology *cosmo, int nz_n, double *z_n, double *n, int *status)
double | ccl_angular_cl (ccl_cosmology *cosmo, int l, CCL_ClTracer *clt1, CCL_ClTracer *clt2, int *status)

## Function Documentation

## ◆ ccl_angular_cl()

double ccl_angular_cl | ( | ccl_cosmology * | cosmo,
|  | int | l,
|  | CCL_ClTracer * | clt1,
|  | CCL_ClTracer * | clt2,
|  | int * | status
| ) |  |

Computes limber power spectrum for two different tracers

Parameters

  cosmo | Cosmological parameters
  clt1 | a Cltracer
  clt2 | a Cltracer
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  void

## ◆ ccl_cl_tracer_free()

void ccl_cl_tracer_free | ( | CCL_ClTracer * | clt | ) |

Destructor for a Cltracer

Parameters

  clt | a Cltracer

Returns
  void

## ◆ ccl_cl_tracer_lensing_new()

CCL_ClTracer* ccl_cl_tracer_lensing_new | ( | ccl_cosmology * | cosmo,
|  | int | has_alignment,
|  | int | nz_n,
|  | double * | z_n,
|  | double * | n,
|  | int | nz_ba,
|  | double * | z_ba,
|  | double * | ba,
|  | int | nz_rf,
|  | double * | z_rf,
|  | double * | rf,
|  | int * | status
| ) |  |

Simplified constructor for a lensing ClTracer.

Parameters

  has_intrinsic_alignment | Set to 1 if you want to compute the IA contribution to shear
  nz_n | Number of bins in z_n and n
  z_n | Redshifts for each redshift interval of n
  n | Number count of objects per redshift interval (Note: arbitrary normalization - renormalized inside)
  nz_ba | Number of bins in z_ba and ba
  z_ba | Redshifts for each redshift interval of ba
  ba | Alignment bias in each redshift bin
  nz_rf | Number of bins in z_f and f
  z_rf | Redshifts for each redshift interval of rf
  rf | Aligned red fraction in each redshift bin
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  CCL_ClTracer object

## ◆ ccl_cl_tracer_lensing_simple_new()

CCL_ClTracer* ccl_cl_tracer_lensing_simple_new | ( | ccl_cosmology * | cosmo,
|  | int | nz_n,
|  | double * | z_n,
|  | double * | n,
|  | int * | status
| ) |  |

Simplified constructor for a lensing ClTracer without intrinsic alignment.

Parameters

  nz_n | Number of bins in z_n and n
  z_n | Redshifts for each redshift interval of n
  n | Number count of objects per redshift interval (Note: arbitrary normalization - renormalized inside)
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  CCL_ClTracer object

## ◆ ccl_cl_tracer_new()

CCL_ClTracer* ccl_cl_tracer_new | ( | ccl_cosmology * | cosmo,
|  | int | tracer_type,
|  | int | has_rsd,
|  | int | has_magnification,
|  | int | has_intrinsic_alignment,
|  | int | nz_n,
|  | double * | z_n,
|  | double * | n,
|  | int | nz_b,
|  | double * | z_b,
|  | double * | b,
|  | int | nz_s,
|  | double * | z_s,
|  | double * | s,
|  | int | nz_ba,
|  | double * | z_ba,
|  | double * | ba,
|  | int | nz_rf,
|  | double * | z_rf,
|  | double * | rf,
|  | int * | status
| ) |  |

Constructor for a ClTracer.

Parameters

  Tracer_type | pass CL_TRACER_NC (number counts) or CL_TRACER_WL (weak lensing)
  has_rsd | Set to 1 if you want to compute the RSD contribution to number counts (0 otherwise)
  has_magnification | Set to 1 if you want to compute the magnification contribution to number counts (0 otherwise)
  has_intrinsic_alignment | Set to 1 if you want to compute the IA contribution to shear
  nz_n | Number of bins in z_n and n
  z_n | Redshifts for each redshift interval of n
  n | Number count of objects per redshift interval (Note: arbitrary normalization - renormalized inside)
  nz_b | Number of bins in z_b and b
  z_b | Redshifts for each redshift interval of b
  b | Clustering bias in each redshift bin
  nz_s | Number of bins in z_s and s
  z_s | Redshifts for each redshift interval of s
  s | Magnification bias in each redshift bin
  nz_ba | Number of bins in z_ba and ba
  z_ba | Redshifts for each redshift interval of ba
  ba | Alignment bias in each redshift bin
  nz_rf | Number of bins in z_f and f
  z_rf | Redshifts for each redshift interval of rf
  rf | Aligned red fraction in each redshift bin

Returns
  CCL_ClTracer object

## ◆ ccl_cl_tracer_number_counts_new()

CCL_ClTracer* ccl_cl_tracer_number_counts_new | ( | ccl_cosmology * | cosmo,
|  | int | has_rsd,
|  | int | has_magnification,
|  | int | nz_n,
|  | double * | z_n,
|  | double * | n,
|  | int | nz_b,
|  | double * | z_b,
|  | double * | b,
|  | int | nz_s,
|  | double * | z_s,
|  | double * | s,
|  | int * | status
| ) |  |

Simplified constructor for a clustering ClTracer.

Parameters

  cosmo | Cosmological parameters
  has_rsd | Set to 1 if you want to compute the RSD contribution to number counts (0 otherwise)
  has_magnification | Set to 1 if you want to compute the magnification contribution to number counts (0 otherwise)
  nz_n | Number of bins in z_n and n
  z_n | Redshifts for each redshift interval of n
  n | Number count of objects per redshift interval (Note: arbitrary normalization - renormalized inside)
  nz_b | Number of bins in z_b and b
  z_b | Redshifts for each redshift interval of b
  b | Clustering bias in each redshift bin
  nz_s | Number of bins in z_s and s
  z_s | Redshifts for each redshift interval of s
  s | Magnification bias in each redshift bin
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  CCL_ClTracer object

## ◆ ccl_cl_tracer_number_counts_simple_new()

CCL_ClTracer* ccl_cl_tracer_number_counts_simple_new | ( | ccl_cosmology * | cosmo,
|  | int | nz_n,
|  | double * | z_n,
|  | double * | n,
|  | int | nz_b,
|  | double * | z_b,
|  | double * | b,
|  | int * | status
| ) |  |

Simplified constructor for a ClTracer without magnification nor RSD.

Parameters

  nz_n | Number of bins in z_n and n
  z_n | Redshifts for each redshift interval of n
  n | Number count of objects per redshift interval (Note: arbitrary normalization - renormalized inside)
  nz_b | Number of bins in z_b and b
  z_b | Redshifts for each redshift interval of b
  b | Clustering bias in each redshift bin
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  CCL_ClTracer object